=================================
Flask Password
=================================
Password hashing for Python 3+ integrated with Flask.

Feedback
===============
Please use the Issues_ for feature requests and troubleshooting usage.

.. |Version| image:: https://badge.fury.io/py/flask-password?
   :target: http://badge.fury.io/py/flask-password

.. |Downloads| image:: https://pypip.in/d/flask-password/badge.svg?
   :target: https://pypi.python.org/pypi/flask-password
   
.. |License| image:: https://pypip.in/license/flask-password/badge.svg?
   :target: https://github.com/viniciuschiele/flask-password/blob/master/LICENSE

.. _Issues: https://github.com/viniciuschiele/flask-password/issues

